OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日历",
    "Individual" : "个人",
    "Group" : "群组",
    "Resource" : "源",
    "Room" : "房间",
    "Unknown" : "未知",
    "Required" : "必填",
    "Optional" : "选填",
    "Does not attend" : "不参加",
    "New event" : "新事件",
    "Attendees" : "参加者",
    "Reminders" : "提醒",
    "Repeating" : "重复",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示进行中的事件",
    "When shared hide this event" : "共享时隐藏本事件",
    "Global" : "全局",
    "None" : "不提醒",
    "never" : "从不",
    "At time of event" : "在事件发生的",
    "5 minutes before" : "5分钟前",
    "10 minutes before" : "10分钟前",
    "15 minutes before" : "15分钟前",
    "30 minutes before" : "30分钟前",
    "1 hour before" : "1小时前",
    "2 hours before" : "2小时前",
    "Custom" : "自定义",
    "Audio" : "声音提醒",
    "E Mail" : "邮件提醒",
    "Pop up" : "弹窗提醒",
    "sec" : "秒",
    "min" : "分钟",
    "hours" : "小时",
    "days" : "天",
    "week" : "周",
    "Week {number} of {year}" : "{year}年的第{number}周",
    "Successfully imported" : "导入成功",
    "Partially imported, 1 failure" : "部分导入成功，1个失败",
    "Partially imported, {n} failures" : "部分导入成功，{n} 个失败",
    "Audio alarm" : "声音提醒",
    "Pop-up" : "弹窗提醒",
    "E-Mail" : "邮件提醒",
    "{type} {time} before the event starts" : "事件开始前 {type} {time} ",
    "{type} {time} before the event ends" : "事件结束前 {type} {time} ",
    "{type} {time} after the event starts" : "事件开始后 {type} {time} ",
    "{type} {time} after the event ends" : "事件结束后 {type} {time} ",
    "{type} at the event's start" : "{type} 事件开始时",
    "{type} at the event's end" : "{type} 事件结束时",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
    "Title of the Event" : "事件标题",
    "starts" : "开始于",
    "ends" : "结束于",
    "All day Event" : "全天事件",
    "Location" : "地点",
    "Delete" : "删除",
    "Cancel" : "取消",
    "More ..." : "更多...",
    "Create" : "创建",
    "Update" : "更新",
    "Close" : "关闭",
    "Description" : "描述",
    "Export" : "导出",
    "Day" : "天",
    "Week" : "星期",
    "Month" : "月",
    "Today" : "今天",
    "Share Calendar" : "共享日历",
    "More" : "更多",
    "Edit" : "编辑",
    "group" : "群组",
    "New Calendar" : "新建日历",
    "Subscriptions" : "订阅",
    "New Subscription" : "新的订阅",
    "Url" : "URL",
    "Edit event" : "编辑事件",
    "Delete Event" : "删除事件",
    "Save Event" : "保存事件",
    "Time" : "时间",
    "Type" : "类型",
    "Relative" : "相对",
    "Absolute" : "绝对",
    "Repeat" : "重复",
    "times every" : "次每",
    "Add" : "增加",
    "from" : "从",
    "to" : "到",
    "Import Calendars" : "导入日历",
    "Analyzing calendar" : "分析日历",
    "The file contains objects incompatible with the selected calendar" : "该文件包含的内容与选择的日历不兼容",
    "New calendar" : "新建日历",
    "Import scheduled" : "导入时间表",
    "Settings" : "设置",
    "Import calendar" : "导入日历",
    "No Calendars selected for import" : "未选择要导入的日历",
    "Primary CalDAV address" : "主要的 CalDAV 地址",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址"
},
"nplurals=1; plural=0;");
